@@ -6,6 +6,7 @@ from flake8_import_order import __version__
 from flake8_import_order.checker import (
     DEFAULT_IMPORT_ORDER_STYLE, ImportOrderChecker,
 )
+from flake8_import_order.styles import lookup_entry_point
 
 
 class Linter(ImportOrderChecker, BaseLinter):
@@ -29,10 +30,11 @@ class Linter(ImportOrderChecker, BaseLinter):
     def run(self, path, **meta):
         self.filename = path
         self.tree = None
-        self.options = dict(
-            {'import_order_style': DEFAULT_IMPORT_ORDER_STYLE},
-            **meta
+        meta.setdefault('import_order_style', DEFAULT_IMPORT_ORDER_STYLE)
+        meta['import_order_style'] = lookup_entry_point(
+            meta['import_order_style']
         )
+        self.options = meta
 
         for error in self.check_order():
             yield error
